@@ -1,47 +1,50 @@
-from .general_functions import *
+from .general_functions import (
+    CustomError,
+    autostringconvert,
+    balance_clims,
+    box_muller,
+    check_ascending_axis,
+    complex_str,
+    copy_maybe_none,
+    det_unit_prefactor,
+    dp,
+    emptytest,
+    fa,
+    fname_makenice,
+    init_logging,
+    inside_sphinx,
+    level_str_to_int,
+    lsafe,
+    lsafen,
+    myfilter,
+    ndgrid,
+    pinvr,
+    process_kwargs,
+    redim_C_to_F,
+    redim_F_to_C,
+    reformat_exp,
+    render_matrix,
+    sech,
+    strm,
+    whereblocks,
+)
+from .plot_funcs.DCCT_function import DCCT
+from .plot_funcs.image import image
 from .core import *
 from .load_files import *
 from .figlist import *
 from .nnls import *
 from .lmfitdata import lmfitdata
-from .DCCT_function import DCCT
+from .lmfitdataGUI import lmfitdataGUI
 from .generate_fake_data import fake_data
 from .dict_utils import make_ndarray, unmake_ndarray
+from .load_files.zenodo import zenodo_upload, create_deposition
 from .datadir import getDATADIR, log_fname, proc_data_target_dir
 from .mpl_utils import (
     plot_label_points,
     figlistret,
     figlistini_old,
 )
-from .general_functions import (
-    CustomError,
-    emptytest,
-    balance_clims,
-    process_kwargs,
-    autostringconvert,
-    check_ascending_axis,
-    level_str_to_int,
-    init_logging,
-    inside_sphinx,
-    strm,
-    reformat_exp,
-    complex_str,
-    render_matrix,
-    redim_F_to_C,
-    redim_C_to_F,
-    fname_makenice,
-    lsafen,
-    lsafe,
-    copy_maybe_none,
-    whereblocks,
-    box_muller,
-    dp,
-    fa,
-    ndgrid,
-    pinvr,
-    sech,
-    myfilter,
-)
 
 # import numpy
 
